# **ess**sans

<span style="font-size:1.2em;font-style:italic;color:#5a5a5a">
  SANS data reduction for the European Spallation Source
  </br></br>
</span>

## Overview

This documentation is under construction.
See the [Sans2d data reduction](examples/sans2d) example for a quick start.

## Table of contents

```{toctree}
---
maxdepth: 2
---

examples/index
api-reference/index
developer/index
about/index
```
